package Catalyst::Plugin::Unicode::Encoding;
use strict;
use warnings;

our $VERSION = '5.90131';
$VERSION =~ tr/_//d;

1;

=head1 NAME

Catalyst::Plugin::Unicode::Encoding - Unicode aware Catalyst

=head1 DESCRIPTION

This plugin has been merged into core.  This package only exists to clean out
any existing versions on your installed system.

=head1 AUTHORS

Catalyst Contributors, see Catalyst.pm

=head1 COPYRIGHT

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
